==> jupyterlab-python-bytecode-0.7.0.tgz: package/lib/index.js <==
import { ICommandPalette, IThemeManager } from '@jupyterlab/apputils';
import { ISettingRegistry, PathExt } from '@jupyterlab/coreutils';
import { IDocumentManager } from '@jupyterlab/docmanager';
import { IFileBrowserFactory } from '@jupyterlab/filebrowser';
import { IEditorTracker } from '@jupyterlab/fileeditor';
import { PythonBytecodePanel } from './panel';
import '../style/index.css';
var CommandIDs;
(function (CommandIDs) {
    /**
     * Create a new panel to show Python Bytecode
     */
    CommandIDs.create = `pythonbytecode:create`;
})(CommandIDs || (CommandIDs = {}));
/**
 * Activate the plugin
 */
let activateByteCodePlugin = async (app, browserFactory, docManager, editorTracker, palette, settingsRegistry, themeManager) => {
    const { commands, serviceManager, shell } = app;
    /**
     * Create a Python bytecode panel for a given path to a Python file
     */
    const createPythonBytecodePanel = async (options) => {
        const settings = await settingsRegistry.load(extension.id);
        const userSettings = settings.composite;
        await serviceManager.ready;
        let panel = new PythonBytecodePanel(Object.assign({ serviceManager,
            docManager,
            themeManager,
            userSettings, selections: options.selections }, options));
        await panel.setup();
        const { panelInsertMode } = userSettings;
        const insertMode = `split-${panelInsertMode}`;
        shell.add(panel, 'main', {
            mode: insertMode,
            ref: options.ref,
        });
        return panel;
    };
    commands.addCommand(CommandIDs.create, {
        execute: args => {
            let widget = editorTracker.currentWidget;
            if (!widget) {
                return;
            }
            let basePath = args['basePath'] ||
                args['cwd'] ||
                browserFactory.defaultBrowser.model.path;
            return createPythonBytecodePanel({
                basePath: basePath,
                path: widget.context.path,
                selections: widget.content.model.selections,
                ref: widget.id,
            });
        },
        isEnabled: () => {
            return (editorTracker.currentWidget !== null &&
                editorTracker.currentWidget === shell.currentWidget);
        },
        isVisible: () => {
            let widget = editorTracker.currentWidget;
            return ((widget && PathExt.extname(widget.context.path) === '.py') || false);
        },
        label: 'Show Python Bytecode',
    });
    app.contextMenu.addItem({
        command: CommandIDs.create,
        selector: '.jp-FileEditor',
    });
    palette.addItem({
        command: CommandIDs.create,
        category: 'File Operations',
    });
};
/**
 * Initialization data for the jupyterlab-python-bytecode extension.
 */
const extension = {
    id: 'jupyterlab-python-bytecode:plugin',
    autoStart: true,
    activate: activateByteCodePlugin,
    requires: [
        IFileBrowserFactory,
        IDocumentManager,
        IEditorTracker,
        ICommandPalette,
        ISettingRegistry,
        IThemeManager,
    ],
};
export default extension;

==> jupyterlab-python-bytecode-1.0.0.tgz: package/lib/index.js <==
import { ICommandPalette, IThemeManager } from '@jupyterlab/apputils';
import { PathExt } from '@jupyterlab/coreutils';
import { IDocumentManager } from '@jupyterlab/docmanager';
import { IFileBrowserFactory } from '@jupyterlab/filebrowser';
import { IEditorTracker } from '@jupyterlab/fileeditor';
import { ISettingRegistry } from '@jupyterlab/settingregistry';
import { PythonBytecodePanel } from './panel';
import '../style/index.css';
var CommandIDs;
(function (CommandIDs) {
    /**
     * Create a new panel to show Python Bytecode
     */
    CommandIDs.create = `pythonbytecode:create`;
})(CommandIDs || (CommandIDs = {}));
/**
 * Activate the plugin
 */
const activateByteCodePlugin = async (app, browserFactory, docManager, editorTracker, palette, settingsRegistry, themeManager) => {
    const { commands, serviceManager, shell } = app;
    /**
     * Create a Python bytecode panel for a given path to a Python file
     */
    const createPythonBytecodePanel = async (options) => {
        const settings = await settingsRegistry.load(extension.id);
        const userSettings = settings.composite;
        await serviceManager.ready;
        const panel = new PythonBytecodePanel(Object.assign({ serviceManager,
            docManager,
            themeManager,
            userSettings, selections: options.selections }, options));
        await panel.setup();
        const { panelInsertMode } = userSettings;
        const mode = `split-${panelInsertMode}`;
        shell.add(panel, 'main', {
            mode,
            ref: options.ref,
        });
        return panel;
    };
    commands.addCommand(CommandIDs.create, {
        execute: args => {
            const widget = editorTracker.currentWidget;
            if (!widget) {
                return;
            }
            const basePath = args['basePath'] ||
                args['cwd'] ||
                browserFactory.defaultBrowser.model.path;
            return createPythonBytecodePanel({
                basePath: basePath,
                path: widget.context.path,
                selections: widget.content.model.selections,
                ref: widget.id,
            });
        },
        isEnabled: () => {
            return (editorTracker.currentWidget !== null &&
                editorTracker.currentWidget === shell.currentWidget);
        },
        isVisible: () => {
            const widget = editorTracker.currentWidget;
            return ((widget && PathExt.extname(widget.context.path) === '.py') || false);
        },
        label: 'Show Python Bytecode',
    });
    app.contextMenu.addItem({
        command: CommandIDs.create,
        selector: '.jp-FileEditor',
    });
    palette.addItem({
        command: CommandIDs.create,
        category: 'File Operations',
    });
};
/**
 * Initialization data for the jupyterlab-python-bytecode extension.
 */
const extension = {
    id: 'jupyterlab-python-bytecode:plugin',
    autoStart: true,
    activate: activateByteCodePlugin,
    requires: [
        IFileBrowserFactory,
        IDocumentManager,
        IEditorTracker,
        ICommandPalette,
        ISettingRegistry,
        IThemeManager,
    ],
};
export default extension;
